@@ -1,34 +1,24 @@
-/***************************************************************************
-                          libacpi.c  -  description
-                             -------------------
-    August 2003 C.  edscott wilson garcia <edscott@imp.mx>: BSD acpi stuff
-    begin                : Feb 10 2003
-    copyright            : (C) 2003 by Noberasco Michele
-    e-mail               : 2001s098@educ.disi.unige.it
- ***************************************************************************/
+/* $Id: libacpi.c 1974 2006-09-06 09:50:27Z nick $
+ *
+ * Copyright (c) 2002 Costantino Pistagna <valvoline@vrlteam.org>
+ * Copyright (c) 2003 Noberasco Michele <2001s098@educ.disi.unige.it>
+ * Copyright (c) 2003 Edscott Wilson Garcia <edscott@imp.mx>
+ *
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Library General Public License as published
+ * by the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.              *
- *                                                                         *
- ***************************************************************************/
-
- /***************************************************************************
-        Originally written by Costantino Pistagna for his wmacpimon
- ***************************************************************************/
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
